Index: wp-includes/pluggable.php
===================================================================
--- wp-includes/pluggable.php	(revision 10289)
+++ wp-includes/pluggable.php	(working copy)
@@ -69,13 +69,13 @@
 function wp_get_current_user() {
 	global $current_user;
 
-	get_currentuserinfo();
+	get_current_user_info();
 
 	return $current_user;
 }
 endif;
 
-if ( !function_exists('get_currentuserinfo') ) :
+if ( !function_exists('get_current_user_info') ) :
 /**
  * Populate global variables with information about the currently logged in user.
  *
@@ -83,13 +83,13 @@
  * will be set to the logged in person. If no user is logged in, then it will
  * set the current user to 0, which is invalid and won't have any permissions.
  *
- * @since 0.71
+ * @since 2.8
  * @uses $current_user Checks if the current user is set
  * @uses wp_validate_auth_cookie() Retrieves current logged in user.
  *
  * @return bool|null False on XMLRPC Request and invalid auth cookie. Null when current user set
  */
-function get_currentuserinfo() {
+function get_current_user_info() {
 	global $current_user;
 
 	if ( defined('XMLRPC_REQUEST') && XMLRPC_REQUEST )
@@ -109,16 +109,16 @@
 }
 endif;
 
-if ( !function_exists('get_userdata') ) :
+if ( !function_exists('get_user_data') ) :
 /**
  * Retrieve user info by user ID.
  *
- * @since 0.71
+ * @since 2.8
  *
  * @param int $user_id User ID
  * @return bool|object False on failure, User DB row object
  */
-function get_userdata( $user_id ) {
+function get_user_data( $user_id ) {
 	global $wpdb;
 
 	$user_id = absint($user_id);
@@ -154,16 +154,16 @@
 }
 endif;
 
-if ( !function_exists('get_userdatabylogin') ) :
+if ( !function_exists('get_user_data_by_login') ) :
 /**
  * Retrieve user info by login name.
  *
- * @since 0.71
+ * @since 2.8
  *
  * @param string $user_login User's username
  * @return bool|object False on failure, User DB row object
  */
-function get_userdatabylogin($user_login) {
+function get_user_data_by_login($user_login) {
 	global $wpdb;
 	$user_login = sanitize_user( $user_login );
 
@@ -397,7 +397,7 @@
 
 	// If we don't have a charset from the input headers
 	if ( !isset( $charset ) ) {
-		$charset = get_bloginfo( 'charset' );
+		$charset = get_blog_info( 'charset' );
 	}
 
 	// Set the content-type and charset
@@ -444,7 +444,7 @@
 	if ( '' == $password )
 		return new WP_Error('empty_password', __('<strong>ERROR</strong>: The password field is empty.'));
 
-	$user = get_userdatabylogin($username);
+	$user = get_user_data_by_login($username);
 
 	if ( !$user || ($user->user_login != $username) ) {
 		do_action( 'wp_login_failed', $username );
@@ -522,7 +522,7 @@
 		return false;
 	}
 
-	$user = get_userdatabylogin($username);
+	$user = get_user_data_by_login($username);
 	if ( ! $user ) {
 		do_action('auth_cookie_bad_username', $cookie_elements);
 		return false;
@@ -548,7 +548,7 @@
  * @return string Authentication cookie contents
  */
 function wp_generate_auth_cookie($user_id, $expiration, $scheme = 'auth') {
-	$user = get_userdata($user_id);
+	$user = get_user_data($user_id);
 
 	$key = wp_hash($user->user_login . '|' . $expiration, $scheme);
 	$hash = hash_hmac('md5', $user->user_login . '|' . $expiration, $key);
@@ -935,7 +935,7 @@
 function wp_notify_postauthor($comment_id, $comment_type='') {
 	$comment = get_comment($comment_id);
 	$post    = get_post($comment->comment_post_ID);
-	$user    = get_userdata( $post->post_author );
+	$user    = get_user_data( $post->post_author );
 
 	if ('' == $user->user_email) return false; // If there's no email to send the comment to
 
@@ -1502,7 +1502,7 @@
 	$email = '';
 	if ( is_numeric($id_or_email) ) {
 		$id = (int) $id_or_email;
-		$user = get_userdata($id);
+		$user = get_user_data($id);
 		if ( $user )
 			$email = $user->user_email;
 	} elseif ( is_object($id_or_email) ) {
@@ -1511,7 +1511,7 @@
 
 		if ( !empty($id_or_email->user_id) ) {
 			$id = (int) $id_or_email->user_id;
-			$user = get_userdata($id);
+			$user = get_user_data($id);
 			if ( $user)
 				$email = $user->user_email;
 		} elseif ( !empty($id_or_email->comment_author_email) ) {
@@ -1578,7 +1578,7 @@
  */
 function wp_setcookie($username, $password = '', $already_md5 = false, $home = '', $siteurl = '', $remember = false) {
 	_deprecated_function( __FUNCTION__, '2.5', 'wp_set_auth_cookie()' );
-	$user = get_userdatabylogin($username);
+	$user = get_user_data_by_login($username);
 	wp_set_auth_cookie($user->ID, $remember);
 }
 endif;
@@ -1718,4 +1718,57 @@
 }
 endif;
 
+if ( !function_exists('get_currentuserinfo') ) :
+/**
+ * Populate global variables with information about the currently logged in user.
+ *
+ * Will set the current user, if the current user is not set. The current user
+ * will be set to the logged in person. If no user is logged in, then it will
+ * set the current user to 0, which is invalid and won't have any permissions.
+ *
+ * @deprecated Use get_current_user_info()
+ * @since 0.71
+ * @uses $current_user Checks if the current user is set
+ * @uses wp_validate_auth_cookie() Retrieves current logged in user.
+ *
+ * @return bool|null False on XMLRPC Request and invalid auth cookie. Null when current user set
+ */
+function get_currentuserinfo() {
+	_deprecated_function( __FUNCTION__, '2.8', 'get_current_user_info()' );
+	return get_current_user_info();
+}
+endif;
+
+if ( !function_exists('get_userdatabylogin') ) :
+/**
+ * Retrieve user info by login name.
+ *
+ * @deprecated Use get_user_data_by_login()
+ * @since 0.71
+ *
+ * @param string $user_login User's username
+ * @return bool|object False on failure, User DB row object
+ */
+function get_userdatabylogin($user_login = '') {
+	_deprecated_function( __FUNCTION__, '2.8', 'get_user_data_by_login()' );
+	return get_user_data_by_login($user_login);
+}
+endif;
+
+if ( !function_exists('get_userdata') ) :
+/**
+ * Retrieve user info by user ID.
+ *
+ * @deprecated use get_user_data()
+ * @since 0.71
+ *
+ * @param int $user_id User ID
+ * @return bool|object False on failure, User DB row object
+ */
+function get_userdata( $user_id = 0 ) {
+	_deprecated_function( __FUNCTION__, '2.8', 'get_user_data()' );
+	return get_user_data($user_id);
+}
+endif;
+
 ?>
Index: wp-includes/script-loader.php
===================================================================
--- wp-includes/script-loader.php	(revision 10289)
+++ wp-includes/script-loader.php	(working copy)
@@ -39,7 +39,7 @@
 		$guessurl = wp_guess_url();
 
 	$scripts->base_url = $guessurl;
-	$scripts->default_version = get_bloginfo( 'version' );
+	$scripts->default_version = get_blog_info( 'version' );
 
 	$scripts->add( 'common', '/wp-admin/js/common.js', array('jquery', 'hoverIntent'), '20081226' );
 	$scripts->add( 'sack', '/wp-includes/js/tw-sack.js', false, '1.6.1' );
@@ -312,8 +312,8 @@
 	if ( ! $guessurl = site_url() )
 		$guessurl = wp_guess_url();
 	$styles->base_url = $guessurl;
-	$styles->default_version = get_bloginfo( 'version' );
-	$styles->text_direction = 'rtl' == get_bloginfo( 'text_direction' ) ? 'rtl' : 'ltr';
+	$styles->default_version = get_blog_info( 'version' );
+	$styles->text_direction = 'rtl' == get_blog_info( 'text_direction' ) ? 'rtl' : 'ltr';
 
 	$rtl_styles = array( 'global', 'colors', 'dashboard', 'ie', 'install', 'login', 'media', 'theme-editor', 'upload', 'widgets', 'press-this', 'plugin-install', 'farbtastic' );
 
Index: wp-includes/category-template.php
===================================================================
--- wp-includes/category-template.php	(revision 10289)
+++ wp-includes/category-template.php	(working copy)
@@ -502,9 +502,9 @@
 
 		if( !empty( $show_option_all ) )
 			if ( 'list' == $style )
-				$output .= '<li><a href="' .  get_bloginfo( 'url' )  . '">' . $show_option_all . '</a></li>';
+				$output .= '<li><a href="' .  get_blog_info( 'url' )  . '">' . $show_option_all . '</a></li>';
 			else
-				$output .= '<a href="' .  get_bloginfo( 'url' )  . '">' . $show_option_all . '</a>';
+				$output .= '<a href="' .  get_blog_info( 'url' )  . '">' . $show_option_all . '</a>';
 
 		if ( empty( $r['current_category'] ) && is_category() )
 			$r['current_category'] = $wp_query->get_queried_object_id();
Index: xmlrpc.php
===================================================================
--- xmlrpc.php	(revision 10289)
+++ xmlrpc.php	(working copy)
@@ -507,7 +507,7 @@
 			}
 
 			// Get the author info.
-			$author = get_userdata($page->post_author);
+			$author = get_user_data($page->post_author);
 
 			$page_template = get_post_meta( $page->ID, '_wp_page_template', true );
 			if( empty( $page_template ) )
@@ -1625,7 +1625,7 @@
 
 		do_action('xmlrpc_call', 'blogger.getUserInfo');
 
-		$user_data = get_userdatabylogin($user_login);
+		$user_data = get_user_data_by_login($user_login);
 
 		$struct = array(
 			'nickname'  => $user_data->nickname,
@@ -2569,7 +2569,7 @@
 			$link = post_permalink($postdata['ID']);
 
 			// Get the author info.
-			$author = get_userdata($postdata['post_author']);
+			$author = get_user_data($postdata['post_author']);
 
 			$allow_comments = ('open' == $postdata['comment_status']) ? 1 : 0;
 			$allow_pings = ('open' == $postdata['ping_status']) ? 1 : 0;
@@ -2684,7 +2684,7 @@
 			$link = post_permalink($entry['ID']);
 
 			// Get the post author info.
-			$author = get_userdata($entry['post_author']);
+			$author = get_user_data($entry['post_author']);
 
 			$allow_comments = ('open' == $entry['comment_status']) ? 1 : 0;
 			$allow_pings = ('open' == $entry['ping_status']) ? 1 : 0;
Index: wp-content/themes/default/archive.php
===================================================================
--- wp-content/themes/default/archive.php	(revision 10289)
+++ wp-content/themes/default/archive.php	(working copy)
@@ -60,7 +60,7 @@
 		} else if ( is_date() ) { // If this is a date archive
 			echo("<h2>Sorry, but there aren't any posts with this date.</h2>");
 		} else if ( is_author() ) { // If this is a category archive
-			$userdata = get_userdatabylogin(get_query_var('author_name'));
+			$userdata = get_user_data_by_login(get_query_var('author_name'));
 			printf("<h2 class='center'>Sorry, but there aren't any posts by %s yet.</h2>", $userdata->display_name);
 		} else {
 			echo("<h2 class='center'>No posts found.</h2>");
Index: wp-links-opml.php
===================================================================
--- wp-links-opml.php	(revision 10289)
+++ wp-links-opml.php	(working copy)
@@ -29,7 +29,7 @@
 <?php the_generator( 'comment' ); ?>
 <opml version="1.0">
 	<head>
-		<title>Links for <?php echo attribute_escape(get_bloginfo('name', 'display').$cat_name); ?></title>
+		<title>Links for <?php echo attribute_escape(get_blog_info('name', 'display').$cat_name); ?></title>
 		<dateCreated><?php echo gmdate("D, d M Y H:i:s"); ?> GMT</dateCreated>
 	</head>
 	<body>
Index: wp-rss2.php
===================================================================
--- wp-rss2.php	(revision 10289)
+++ wp-rss2.php	(working copy)
@@ -7,6 +7,6 @@
  */
 
 require( './wp-load.php' );
-wp_redirect( get_bloginfo( 'rss2_url' ), 301 );
+wp_redirect( get_blog_info( 'rss2_url' ), 301 );
 
 ?>
\ No newline at end of file
Index: wp-commentsrss2.php
===================================================================
--- wp-commentsrss2.php	(revision 10289)
+++ wp-commentsrss2.php	(working copy)
@@ -7,6 +7,6 @@
  */
 
 require( './wp-load.php' );
-wp_redirect( get_bloginfo( 'comments_rss2_url' ), 301 );
+wp_redirect( get_blog_info( 'comments_rss2_url' ), 301 );
 
 ?>
\ No newline at end of file
Index: wp-atom.php
===================================================================
--- wp-atom.php	(revision 10289)
+++ wp-atom.php	(working copy)
@@ -7,6 +7,6 @@
  */
 
 require( './wp-load.php' );
-wp_redirect( get_bloginfo( 'atom_url' ), 301 );
+wp_redirect( get_blog_info( 'atom_url' ), 301 );
 
 ?>
\ No newline at end of file
Index: wp-admin/admin-ajax.php
===================================================================
--- wp-admin/admin-ajax.php	(revision 10289)
+++ wp-admin/admin-ajax.php	(working copy)
@@ -818,7 +818,7 @@
 		if ( $last = wp_check_post_lock( $post->ID ) ) {
 			$do_autosave = $do_lock = false;
 
-			$last_user = get_userdata( $last );
+			$last_user = get_user_data( $last );
 			$last_user_name = $last_user ? $last_user->display_name : __( 'Someone' );
 			$data = new WP_Error( 'locked', sprintf(
 				$_POST['post_type'] == 'page' ? __( 'Autosave disabled: %s is currently editing this page.' ) : __( 'Autosave disabled: %s is currently editing this post.' ),
@@ -903,9 +903,9 @@
 	}
 	$current_user = wp_get_current_user();
 	if ( is_array($closed) )
-		update_usermeta($current_user->ID, 'closedpostboxes_'.$page, $closed);
+		update_user_meta($current_user->ID, 'closedpostboxes_'.$page, $closed);
 	if ( is_array($hidden) )
-		update_usermeta($current_user->ID, 'meta-box-hidden_'.$page, $hidden);
+		update_user_meta($current_user->ID, 'meta-box-hidden_'.$page, $hidden);
 break;
 case 'hidden-columns' :
 	check_ajax_referer( 'hiddencolumns', 'hiddencolumnsnonce' );
@@ -917,7 +917,7 @@
 	}
 	$current_user = wp_get_current_user();
 	if ( is_array($hidden) )
-		update_usermeta($current_user->ID, "manage-$page-columns-hidden", $hidden);
+		update_user_meta($current_user->ID, "manage-$page-columns-hidden", $hidden);
 break;
 case 'get-permalink':
 	check_ajax_referer( 'getpermalink', 'getpermalinknonce' );
@@ -946,7 +946,7 @@
 	}
 
 	if ( $last = wp_check_post_lock( $post_ID ) ) {
-		$last_user = get_userdata( $last );
+		$last_user = get_user_data( $last );
 		$last_user_name = $last_user ? $last_user->display_name : __( 'Someone' );
 		printf( $_POST['post_type'] == 'page' ? __( 'Saving is disabled: %s is currently editing this page.' ) : __( 'Saving is disabled: %s is currently editing this post.' ),	wp_specialchars( $last_user_name ) );
 		exit;
Index: wp-admin/includes/upgrade.php
===================================================================
--- wp-admin/includes/upgrade.php	(revision 10289)
+++ wp-admin/includes/upgrade.php	(working copy)
@@ -382,7 +382,7 @@
 	}
 
 	// Get the GMT offset, we'll use that later on
-	$all_options = get_alloptions_110();
+	$all_options = get_all_options_110();
 
 	$time_difference = $all_options->time_difference;
 
@@ -512,23 +512,23 @@
 	$users = $wpdb->get_results("SELECT * FROM $wpdb->users");
 	foreach ( $users as $user ) :
 		if ( !empty( $user->user_firstname ) )
-			update_usermeta( $user->ID, 'first_name', $wpdb->escape($user->user_firstname) );
+			update_user_meta( $user->ID, 'first_name', $wpdb->escape($user->user_firstname) );
 		if ( !empty( $user->user_lastname ) )
-			update_usermeta( $user->ID, 'last_name', $wpdb->escape($user->user_lastname) );
+			update_user_meta( $user->ID, 'last_name', $wpdb->escape($user->user_lastname) );
 		if ( !empty( $user->user_nickname ) )
-			update_usermeta( $user->ID, 'nickname', $wpdb->escape($user->user_nickname) );
+			update_user_meta( $user->ID, 'nickname', $wpdb->escape($user->user_nickname) );
 		if ( !empty( $user->user_level ) )
-			update_usermeta( $user->ID, $wpdb->prefix . 'user_level', $user->user_level );
+			update_user_meta( $user->ID, $wpdb->prefix . 'user_level', $user->user_level );
 		if ( !empty( $user->user_icq ) )
-			update_usermeta( $user->ID, 'icq', $wpdb->escape($user->user_icq) );
+			update_user_meta( $user->ID, 'icq', $wpdb->escape($user->user_icq) );
 		if ( !empty( $user->user_aim ) )
-			update_usermeta( $user->ID, 'aim', $wpdb->escape($user->user_aim) );
+			update_user_meta( $user->ID, 'aim', $wpdb->escape($user->user_aim) );
 		if ( !empty( $user->user_msn ) )
-			update_usermeta( $user->ID, 'msn', $wpdb->escape($user->user_msn) );
+			update_user_meta( $user->ID, 'msn', $wpdb->escape($user->user_msn) );
 		if ( !empty( $user->user_yim ) )
-			update_usermeta( $user->ID, 'yim', $wpdb->escape($user->user_icq) );
+			update_user_meta( $user->ID, 'yim', $wpdb->escape($user->user_icq) );
 		if ( !empty( $user->user_description ) )
-			update_usermeta( $user->ID, 'description', $wpdb->escape($user->user_description) );
+			update_user_meta( $user->ID, 'description', $wpdb->escape($user->user_description) );
 
 		if ( isset( $user->user_idmode ) ):
 			$idmode = $user->user_idmode;
@@ -543,11 +543,11 @@
 		endif;
 
 		// FIXME: RESET_CAPS is temporary code to reset roles and caps if flag is set.
-		$caps = get_usermeta( $user->ID, $wpdb->prefix . 'capabilities');
+		$caps = get_user_meta( $user->ID, $wpdb->prefix . 'capabilities');
 		if ( empty($caps) || defined('RESET_CAPS') ) {
-			$level = get_usermeta($user->ID, $wpdb->prefix . 'user_level');
+			$level = get_user_meta($user->ID, $wpdb->prefix . 'user_level');
 			$role = translate_level_to_role($level);
-			update_usermeta( $user->ID, $wpdb->prefix . 'capabilities', array($role => true) );
+			update_user_meta( $user->ID, $wpdb->prefix . 'capabilities', array($role => true) );
 		}
 
 	endforeach;
@@ -1011,11 +1011,11 @@
 /**
  * Retrieve all options as it was for 1.2.
  *
- * @since 1.2.0
+ * @since 2.8
  *
  * @return array List of options.
  */
-function get_alloptions_110() {
+function get_all_options_110() {
 	global $wpdb;
 	if ($options = $wpdb->get_results("SELECT option_name, option_value FROM $wpdb->options")) {
 		foreach ($options as $option) {
Index: wp-admin/includes/template.php
===================================================================
--- wp-admin/includes/template.php	(revision 10289)
+++ wp-admin/includes/template.php	(working copy)
@@ -1804,7 +1804,7 @@
 		$short_url = substr( $short_url, 0, -1 );
 	if ( strlen( $short_url ) > 35 )
 		$short_url = substr( $short_url, 0, 32 ).'...';
-	$numposts = get_usernumposts( $user_object->ID );
+	$numposts = get_user_num_posts( $user_object->ID );
 	$checkbox = '';
 	// Check if the user for this row is editable 
 	if ( current_user_can( 'edit_user', $user_object->ID ) ) {
Index: wp-admin/includes/user.php
===================================================================
--- wp-admin/includes/user.php	(revision 10289)
+++ wp-admin/includes/user.php	(working copy)
@@ -48,7 +48,7 @@
 	if ( $user_id != 0 ) {
 		$update = true;
 		$user->ID = (int) $user_id;
-		$userdata = get_userdata( $user_id );
+		$userdata = get_user_data( $user_id );
 		$user->user_login = $wpdb->escape( $userdata->user_login );
 	} else {
 		$update = false;
Index: wp-admin/includes/export.php
===================================================================
--- wp-admin/includes/export.php	(revision 10289)
+++ wp-admin/includes/export.php	(working copy)
@@ -122,7 +122,7 @@
 	}
 	// wp: the blog url
 	else {
-		return get_bloginfo_rss('url');
+		return get_blog_info_rss('url');
 	}
 }
 
@@ -212,7 +212,7 @@
 	echo $the_list;
 }
 
-echo '<?xml version="1.0" encoding="' . get_bloginfo('charset') . '"?' . ">\n";
+echo '<?xml version="1.0" encoding="' . get_blog_info('charset') . '"?' . ">\n";
 
 ?>
 <!-- This is a WordPress eXtended RSS file generated by WordPress as an export of your blog. -->
@@ -244,7 +244,7 @@
 	<title><?php bloginfo_rss('name'); ?></title>
 	<link><?php bloginfo_rss('url') ?></link>
 	<description><?php bloginfo_rss("description") ?></description>
-	<pubDate><?php echo mysql2date('D, d M Y H:i:s +0000', get_lastpostmodified('GMT'), false); ?></pubDate>
+	<pubDate><?php echo mysql2date('D, d M Y H:i:s +0000', get_last_post_modified('GMT'), false); ?></pubDate>
 	<generator>http://wordpress.org/?v=<?php bloginfo_rss('version'); ?></generator>
 	<language><?php echo get_option('rss_language'); ?></language>
 	<wp:wxr_version><?php echo WXR_VERSION; ?></wp:wxr_version>
Index: wp-admin/post.php
===================================================================
--- wp-admin/post.php	(revision 10289)
+++ wp-admin/post.php	(working copy)
@@ -149,7 +149,7 @@
 
 	if ( current_user_can('edit_post', $post_ID) ) {
 		if ( $last = wp_check_post_lock( $post->ID ) ) {
-			$last_user = get_userdata( $last );
+			$last_user = get_user_data( $last );
 			$last_user_name = $last_user ? $last_user->display_name : __('Somebody');
 			$message = sprintf( __( 'Warning: %s is currently editing this post' ), wp_specialchars( $last_user_name ) );
 			$message = str_replace( "'", "\'", "<div class='error'><p>$message</p></div>" );
Index: wp-admin/edit-page-form.php
===================================================================
--- wp-admin/edit-page-form.php	(revision 10289)
+++ wp-admin/edit-page-form.php	(working copy)
@@ -458,7 +458,7 @@
 <?php
 	if ($post_ID) {
 		if ( $last_id = get_post_meta($post_ID, '_edit_last', true) ) {
-			$last_user = get_userdata($last_id);
+			$last_user = get_user_data($last_id);
 			printf(__('Last edited by %1$s on %2$s at %3$s'), wp_specialchars( $last_user->display_name ), mysql2date(get_option('date_format'), $post->post_modified), mysql2date(get_option('time_format'), $post->post_modified));
 		} else {
 			printf(__('Last edited on %1$s at %2$s'), mysql2date(get_option('date_format'), $post->post_modified), mysql2date(get_option('time_format'), $post->post_modified));
Index: wp-admin/gears-manifest.php
===================================================================
--- wp-admin/gears-manifest.php	(revision 10289)
+++ wp-admin/gears-manifest.php	(working copy)
@@ -58,7 +58,7 @@
 /**
  * @ignore
  */
-function get_bloginfo() {}
+function get_blog_info() {}
 
 /**
  * @ignore
Index: wp-admin/import/dotclear.php
===================================================================
--- wp-admin/import/dotclear.php	(revision 10289)
+++ wp-admin/import/dotclear.php	(working copy)
@@ -339,7 +339,7 @@
 				$name = $wpdb->escape(csc ($name));
 				$RealName = $wpdb->escape(csc ($user_pseudo));
 
-				if($uinfo = get_userdatabylogin($name))
+				if($uinfo = get_user_data_by_login($name))
 				{
 
 					$ret_id = wp_insert_user(array(
@@ -376,10 +376,10 @@
 				else if(2  <= $wp_perms) { $user->set_role('contributor'); }
 				else                     { $user->set_role('subscriber'); }
 
-				update_usermeta( $ret_id, 'wp_user_level', $wp_perms);
-				update_usermeta( $ret_id, 'rich_editing', 'false');
-				update_usermeta( $ret_id, 'first_name', csc ($user_prenom));
-				update_usermeta( $ret_id, 'last_name', csc ($user_nom));
+				update_user_meta( $ret_id, 'wp_user_level', $wp_perms);
+				update_user_meta( $ret_id, 'rich_editing', 'false');
+				update_user_meta( $ret_id, 'first_name', csc ($user_prenom));
+				update_user_meta( $ret_id, 'last_name', csc ($user_nom));
 			}// End foreach($users as $user)
 
 			// Store id translation array for future use
@@ -417,7 +417,7 @@
 				$comment_status_map = array (0 => 'closed', 1 => 'open');
 
 				//Can we do this more efficiently?
-				$uinfo = ( get_userdatabylogin( $user_id ) ) ? get_userdatabylogin( $user_id ) : 1;
+				$uinfo = ( get_user_data_by_login( $user_id ) ) ? get_user_data_by_login( $user_id ) : 1;
 				$authorid = ( is_object( $uinfo ) ) ? $uinfo->ID : $uinfo ;
 
 				$Title = $wpdb->escape(csc ($post_titre));
Index: wp-admin/import/textpattern.php
===================================================================
--- wp-admin/import/textpattern.php	(revision 10289)
+++ wp-admin/import/textpattern.php	(working copy)
@@ -228,7 +228,7 @@
 				$name = $wpdb->escape($name);
 				$RealName = $wpdb->escape($RealName);
 
-				if($uinfo = get_userdatabylogin($name))
+				if($uinfo = get_user_data_by_login($name))
 				{
 
 					$ret_id = wp_insert_user(array(
@@ -265,8 +265,8 @@
 				if('2'  == $transperms[$privs]) { $user->set_role('contributor'); }
 				if('0'  == $transperms[$privs]) { $user->set_role('subscriber'); }
 
-				update_usermeta( $ret_id, 'wp_user_level', $transperms[$privs] );
-				update_usermeta( $ret_id, 'rich_editing', 'false');
+				update_user_meta( $ret_id, 'wp_user_level', $transperms[$privs] );
+				update_user_meta( $ret_id, 'rich_editing', 'false');
 			}// End foreach($users as $user)
 
 			// Store id translation array for future use
@@ -303,7 +303,7 @@
 				$stattrans = array(1 => 'draft', 2 => 'private', 3 => 'draft', 4 => 'publish', 5 => 'publish');
 
 				//Can we do this more efficiently?
-				$uinfo = ( get_userdatabylogin( $AuthorID ) ) ? get_userdatabylogin( $AuthorID ) : 1;
+				$uinfo = ( get_user_data_by_login( $AuthorID ) ) ? get_user_data_by_login( $AuthorID ) : 1;
 				$authorid = ( is_object( $uinfo ) ) ? $uinfo->ID : $uinfo ;
 
 				$Title = $wpdb->escape($Title);
@@ -582,7 +582,7 @@
 	{
 		echo '<p>'.__('Welcome to WordPress.  We hope (and expect!) that you will find this platform incredibly rewarding!  As a new WordPress user coming from Textpattern, there are some things that we would like to point out.  Hopefully, they will help your transition go as smoothly as possible.').'</p>';
 		echo '<h3>'.__('Users').'</h3>';
-		echo '<p>'.sprintf(__('You have already setup WordPress and have been assigned an administrative login and password.  Forget it.  You didn&#8217;t have that login in Textpattern, why should you have it here?  Instead we have taken care to import all of your users into our system.  Unfortunately there is one downside.  Because both WordPress and Textpattern uses a strong encryption hash with passwords, it is impossible to decrypt it and we are forced to assign temporary passwords to all your users.  <strong>Every user has the same username, but their passwords are reset to password123.</strong>  So <a href="%1$s">Login</a> and change it.'), get_bloginfo( 'wpurl' ) . '/wp-login.php').'</p>';
+		echo '<p>'.sprintf(__('You have already setup WordPress and have been assigned an administrative login and password.  Forget it.  You didn&#8217;t have that login in Textpattern, why should you have it here?  Instead we have taken care to import all of your users into our system.  Unfortunately there is one downside.  Because both WordPress and Textpattern uses a strong encryption hash with passwords, it is impossible to decrypt it and we are forced to assign temporary passwords to all your users.  <strong>Every user has the same username, but their passwords are reset to password123.</strong>  So <a href="%1$s">Login</a> and change it.'), get_blog_info( 'wpurl' ) . '/wp-login.php').'</p>';
 		echo '<h3>'.__('Preserving Authors').'</h3>';
 		echo '<p>'.__('Secondly, we have attempted to preserve post authors.  If you are the only author or contributor to your blog, then you are safe.  In most cases, we are successful in this preservation endeavor.  However, if we cannot ascertain the name of the writer due to discrepancies between database tables, we assign it to you, the administrative user.').'</p>';
 		echo '<h3>'.__('Textile').'</h3>';
@@ -594,7 +594,7 @@
 		echo '<li>'.__('<a href="http://wordpress.org/support/">The WordPress support forums</a>').'</li>';
 		echo '<li>'.__('<a href="http://codex.wordpress.org">The Codex (In other words, the WordPress Bible)</a>').'</li>';
 		echo '</ul>';
-		echo '<p>'.sprintf(__('That&#8217;s it! What are you waiting for? Go <a href="%1$s">login</a>!'), get_bloginfo( 'wpurl' ) . '/wp-login.php').'</p>';
+		echo '<p>'.sprintf(__('That&#8217;s it! What are you waiting for? Go <a href="%1$s">login</a>!'), get_blog_info( 'wpurl' ) . '/wp-login.php').'</p>';
 	}
 
 	function db_form()
Index: wp-admin/import/wordpress.php
===================================================================
--- wp-admin/import/wordpress.php	(revision 10289)
+++ wp-admin/import/wordpress.php	(working copy)
@@ -168,7 +168,7 @@
 
 			if ( !empty($_POST['user_select'][$i]) ) {
 				// an existing user was selected in the dropdown list
-				$user = get_userdata( intval($_POST['user_select'][$i]) );
+				$user = get_user_data( intval($_POST['user_select'][$i]) );
 				if ( isset($user->ID) )
 					$this->author_ids[$in_author_name] = $user->ID;
 			}
Index: wp-admin/edit-form-advanced.php
===================================================================
--- wp-admin/edit-form-advanced.php	(revision 10289)
+++ wp-admin/edit-form-advanced.php	(working copy)
@@ -603,7 +603,7 @@
 	if ( $post_ID ) {
 		echo '<span id="last-edit">';
 		if ( $last_id = get_post_meta($post_ID, '_edit_last', true) ) {
-			$last_user = get_userdata($last_id);
+			$last_user = get_user_data($last_id);
 			printf(__('Last edited by %1$s on %2$s at %3$s'), wp_specialchars( $last_user->display_name ), mysql2date(get_option('date_format'), $post->post_modified), mysql2date(get_option('time_format'), $post->post_modified));
 		} else {
 			printf(__('Last edited on %1$s at %2$s'), mysql2date(get_option('date_format'), $post->post_modified), mysql2date(get_option('time_format'), $post->post_modified));
Index: wp-admin/menu.php
===================================================================
--- wp-admin/menu.php	(revision 10289)
+++ wp-admin/menu.php	(working copy)
@@ -191,7 +191,7 @@
 
 unset($id);
 
-function add_cssclass($add, $class) {
+function add_css_class($add, $class) {
 	$class = empty($class) ? $add : $class .= ' ' . $add;
 	return $class;
 }
@@ -205,7 +205,7 @@
 		$i++;
 
 		if ( 0 == $order ) { // dashboard is always shown/single
-			$menu[0][4] = add_cssclass('menu-top-first menu-top-last', $top[4]);
+			$menu[0][4] = add_css_class('menu-top-first menu-top-last', $top[4]);
 			continue;
 		}
 
@@ -213,20 +213,20 @@
 			$first = true;
 			if ( $lastorder ) {
 				$c = $menu[$lastorder][4];
-				$menu[$lastorder][4] = add_cssclass('menu-top-last', $c);
+				$menu[$lastorder][4] = add_css_class('menu-top-last', $c);
 			}
 			continue;
 		}
 
 		if ( $first ) {
 			$c = $menu[$order][4];
-			$menu[$order][4] = add_cssclass('menu-top-first', $c);
+			$menu[$order][4] = add_css_class('menu-top-first', $c);
 			$first = false;
 		}
 
 		if ( $mc == $i ) { // last item
 			$c = $menu[$order][4];
-			$menu[$order][4] = add_cssclass('menu-top-last', $c);
+			$menu[$order][4] = add_css_class('menu-top-last', $c);
 		}
 
 		$lastorder = $order;
Index: wp-admin/admin-header.php
===================================================================
--- wp-admin/admin-header.php	(revision 10289)
+++ wp-admin/admin-header.php	(working copy)
@@ -91,7 +91,7 @@
 <div id="wpcontent">
 <div id="wphead">
 <?php
-$blog_name = get_bloginfo('name', 'display');
+$blog_name = get_blog_info('name', 'display');
 if ( '' == $blog_name ) {
 	$blog_name = '&nbsp;';
 } else {
@@ -110,7 +110,7 @@
 }
 ?>
 
-<img id="header-logo" src="../wp-includes/images/blank.gif" alt="" width="32" height="32" /> <h1 <?php echo $title_class ?>><a href="<?php echo trailingslashit( get_bloginfo('url') ); ?>" title="<?php _e('Visit site') ?>"><?php echo $blog_name ?> <span>&larr; <?php _e('Visit site') ?></span></a></h1>
+<img id="header-logo" src="../wp-includes/images/blank.gif" alt="" width="32" height="32" /> <h1 <?php echo $title_class ?>><a href="<?php echo trailingslashit( get_blog_info('url') ); ?>" title="<?php _e('Visit site') ?>"><?php echo $blog_name ?> <span>&larr; <?php _e('Visit site') ?></span></a></h1>
 
 <div id="wphead-info">
 <div id="user_info">
Index: wp-admin/user-edit.php
===================================================================
--- wp-admin/user-edit.php	(revision 10289)
+++ wp-admin/user-edit.php	(working copy)
@@ -97,7 +97,7 @@
 	} else {
 		wp_die(__('Invalid user ID.'));
 	}
-} elseif ( !get_userdata($user_id) ) {
+} elseif ( !get_user_data($user_id) ) {
 	wp_die( __('Invalid user ID.') );
 }
 
Index: wp-admin/page.php
===================================================================
--- wp-admin/page.php	(revision 10289)
+++ wp-admin/page.php	(working copy)
@@ -114,7 +114,7 @@
 
 	if ( current_user_can('edit_page', $page_ID) ) {
 		if ( $last = wp_check_post_lock( $post->ID ) ) {
-			$last_user = get_userdata( $last );
+			$last_user = get_user_data( $last );
 			$last_user_name = $last_user ? $last_user->display_name : __('Somebody');
 			$message = sprintf( __( 'Warning: %s is currently editing this page' ), wp_specialchars( $last_user_name ) );
 			$message = str_replace( "'", "\'", "<div class='error'><p>$message</p></div>" );
Index: wp-admin/export.php
===================================================================
--- wp-admin/export.php	(revision 10289)
+++ wp-admin/export.php	(working copy)
@@ -41,7 +41,7 @@
 <?php
 $authors = $wpdb->get_col( "SELECT post_author FROM $wpdb->posts GROUP BY post_author" );
 foreach ( $authors as $id ) {
-	$o = get_userdata( $id );
+	$o = get_user_data( $id );
 	echo "<option value='$o->ID'>$o->display_name</option>";
 }
 ?>
Index: wp-admin/edit-pages.php
===================================================================
--- wp-admin/edit-pages.php	(revision 10289)
+++ wp-admin/edit-pages.php	(working copy)
@@ -282,7 +282,7 @@
 		// Make sure comments, post, and post_author are cached
 		update_comment_cache($comments);
 		$post = get_post($id);
-		$authordata = get_userdata($post->post_author);
+		$authordata = get_user_data($post->post_author);
 	?>
 
 <br class="clear" />
Index: wp-admin/themes.php
===================================================================
--- wp-admin/themes.php	(revision 10289)
+++ wp-admin/themes.php	(working copy)
@@ -31,7 +31,7 @@
 <?php if ( ! validate_current_theme() ) : ?>
 <div id="message1" class="updated fade"><p><?php _e('The active theme is broken.  Reverting to the default theme.'); ?></p></div>
 <?php elseif ( isset($_GET['activated']) ) : ?>
-<div id="message2" class="updated fade"><p><?php printf(__('New theme activated. <a href="%s">Visit site</a>'), get_bloginfo('url') . '/'); ?></p></div>
+<div id="message2" class="updated fade"><p><?php printf(__('New theme activated. <a href="%s">Visit site</a>'), get_blog_info('url') . '/'); ?></p></div>
 <?php endif; ?>
 
 <?php
Index: wp-admin/categories.php
===================================================================
--- wp-admin/categories.php	(revision 10289)
+++ wp-admin/categories.php	(working copy)
@@ -40,7 +40,7 @@
 	if ( !current_user_can('manage_categories') )
 		wp_die(__('Cheatin&#8217; uh?'));
 
-	$cat_name = get_catname($cat_ID);
+	$cat_name = get_cat_name($cat_ID);
 
 	// Don't delete the default cats.
     if ( $cat_ID == get_option('default_category') )
@@ -60,7 +60,7 @@
 		wp_die( __('You are not allowed to delete categories.') );
 
 	foreach ( (array) $_GET['delete'] as $cat_ID ) {
-		$cat_name = get_catname($cat_ID);
+		$cat_name = get_cat_name($cat_ID);
 
 		// Don't delete the default cats.
 		if ( $cat_ID == get_option('default_category') )
@@ -233,7 +233,7 @@
 </form>
 
 <div class="form-wrap">
-<p><?php printf(__('<strong>Note:</strong><br />Deleting a category does not delete the posts in that category. Instead, posts that were only assigned to the deleted category are set to the category <strong>%s</strong>.'), apply_filters('the_category', get_catname(get_option('default_category')))) ?></p>
+<p><?php printf(__('<strong>Note:</strong><br />Deleting a category does not delete the posts in that category. Instead, posts that were only assigned to the deleted category are set to the category <strong>%s</strong>.'), apply_filters('the_category', get_cat_name(get_option('default_category')))) ?></p>
 <p><?php printf(__('Categories can be selectively converted to tags using the <a href="%s">category to tag converter</a>.'), 'admin.php?import=wp-cat2tag') ?></p>
 </div>
 
Index: wp-feed.php
===================================================================
--- wp-feed.php	(revision 10289)
+++ wp-feed.php	(working copy)
@@ -7,6 +7,6 @@
  */
 
 require( './wp-load.php' );
-wp_redirect( get_bloginfo( 'rss2_url' ), 301 );
+wp_redirect( get_blog_info( 'rss2_url' ), 301 );
 
 ?>
\ No newline at end of file

Index: wp-includes/feed.php
===================================================================
--- wp-includes/feed.php	(revision 10289)
+++ wp-includes/feed.php	(working copy)
@@ -12,28 +12,28 @@
 /**
  * RSS container for the bloginfo function.
  *
  * You can retrieve anything that you can using the get_bloginfo() function.
  * Everything will be stripped of tags and characters converted, when the values
  * are retrieved for use in the feeds.
  *
  * @package WordPress
  * @subpackage Feed
  * @since 1.5.1
  * @uses apply_filters() Calls 'get_bloginfo_rss' hook with two parameters.
  * @see get_bloginfo() For the list of possible values to display.
  *
  * @param string $show See get_bloginfo() for possible values.
  * @return string
  */
-function get_bloginfo_rss($show = '') {
-	$info = strip_tags(get_bloginfo($show));
+function get_blog_info_rss($show = '') {
+	$info = strip_tags(get_blog_info($show));
 	return apply_filters('get_bloginfo_rss', convert_chars($info), $show);
 }
 
 /**
  * Display RSS container for the bloginfo function.
  *
  * You can retrieve anything that you can using the get_bloginfo() function.
  * Everything will be stripped of tags and characters converted, when the values
  * are retrieved for use in the feeds.
  *
@@ -41,12 +41,12 @@
  * @subpackage Feed
  * @since 0.71
  * @uses apply_filters() Calls 'bloginfo_rss' hook with two parameters.
  * @see get_bloginfo() For the list of possible values to display.
  *
  * @param string $show See get_bloginfo() for possible values.
  */
 function bloginfo_rss($show = '') {
-	echo apply_filters('bloginfo_rss', get_bloginfo_rss($show), $show);
+	echo apply_filters('bloginfo_rss', get_blog_info_rss($show), $show);
 }
 
 /**
@@ -335,7 +335,7 @@
 		if ( 'rdf' == $type )
 			$the_list .= "\n\t\t<dc:subject><![CDATA[$cat_name]]></dc:subject>\n";
 		elseif ( 'atom' == $type )
-			$the_list .= sprintf( '<category scheme="%1$s" term="%2$s" />', attribute_escape( apply_filters( 'get_bloginfo_rss', get_bloginfo( 'url' ) ) ), attribute_escape( $cat_name ) );
+			$the_list .= sprintf( '<category scheme="%1$s" term="%2$s" />', attribute_escape( apply_filters( 'get_blog_info_rss', get_blog_info( 'url' ) ) ), attribute_escape( $cat_name ) );
 		else
 			$the_list .= "\n\t\t<category><![CDATA[" . html_entity_decode( $cat_name ) . "]]></category>\n";
 	}
@@ -367,7 +367,7 @@
  * @since 2.2.0
  */
 function html_type_rss() {
-	$type = get_bloginfo('html_type');
+	$type = get_blog_info('html_type');
 	if (strpos($type, 'xhtml') !== false)
 		$type = 'xhtml';
 	else
@@ -12,28 +12,28 @@
  * RSS container for the bloginfo function.
  *
- * You can retrieve anything that you can using the get_bloginfo() function.
+ * You can retrieve anything that you can using the get_blog_info() function.
  * Everything will be stripped of tags and characters converted, when the values
  * are retrieved for use in the feeds.
@@ -12,28 +12,28 @@
  * @package WordPress
  * @subpackage Feed
- * @since 1.5.1
- * @uses apply_filters() Calls 'get_bloginfo_rss' hook with two parameters.
- * @see get_bloginfo() For the list of possible values to display.
+ * @since 2.8
+ * @uses apply_filters() Calls 'get_blog_info_rss' hook with two parameters.
+ * @see get_blog_info() For the list of possible values to display.
  *
@@ -12,28 +12,28 @@
  *
- * @param string $show See get_bloginfo() for possible values.
+ * @param string $show See get_blog_info() for possible values.
  * @return string
  */
@@ -12,28 +12,28 @@
  * Display RSS container for the bloginfo function.
  *
- * You can retrieve anything that you can using the get_bloginfo() function.
+ * You can retrieve anything that you can using the get_blog_info() function.
  * Everything will be stripped of tags and characters converted, when the values
  * are retrieved for use in the feeds.
@@ -41,12 +41,12 @@
  * @since 0.71
  * @uses apply_filters() Calls 'bloginfo_rss' hook with two parameters.
- * @see get_bloginfo() For the list of possible values to display.
+ * @see get_blog_info() For the list of possible values to display.
  *
@@ -41,12 +41,12 @@
  *
- * @param string $show See get_bloginfo() for possible values.
+ * @param string $show See get_blog_info() for possible values.
  */
 function bloginfo_rss($show = '') {